@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp qw/croak/;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Exporter 'import';
 
@@ -21,31 +21,31 @@ sub return_modifiers {
             croak "Can't find method <$_> in <$_[0]>";
         }
     }
-    return %modifiers;
+    return $_[2] ? \%modifiers : %modifiers;
 }
 
 sub return_has {
-    return {return_modifiers($_[0], [qw/has/])}->{has};
+ 	return_modifiers($_[0], [qw/has/], 1)->{has};
 }
 
 sub return_with {
-    return {return_modifiers($_[0], [qw/with/])}->{with};
+	return_modifiers($_[0], [qw/with/], 1)->{with};
 }
 
 sub return_around {
-    return {return_modifiers($_[0], [qw/around/])}->{around};
+	return_modifiers($_[0], [qw/around/], 1)->{around};
 }
 
 sub return_extends {
-    return {return_modifiers($_[0], [qw/extends/])}->{extends};
+    	return_modifiers($_[0], [qw/extends/], 1)->{extends};
 }
 
 sub return_before {
-    return {return_modifiers($_[0], [qw/before/])}->{before};
+    	return_modifiers($_[0], [qw/before/], 1)->{before};
 }
 
 sub return_after {
-    return {return_modifiers($_[0], [qw/after/])}->{after};
+    	return_modifiers($_[0], [qw/after/], 1)->{after};
 }
 
 =head1 NAME
@@ -54,7 +54,7 @@ MooX::ReturnModifiers - Returns Moo Modifiers as a Hash
 
 =head1 VERSION
 
-ersion 0.06
+Version 0.07
 
 =head1 SYNOPSIS
 
